import os, json, datetime, conf.config as config

from werkzeug.security import generate_password_hash
from models.user import User
from models.key import Key, KeyType, KeyState
from models.key_history import KeyHistory
from models.product import Product
from models.token import Token
from models.pool import Pool
from models.licensing_server_setup import LicensingServerSetup

from lib.server import create_app, db

def getval(value):
    if '=' in value:
        return value.split('=')[1]
    return ''

def get_product(value):

    if value == 'NSC':
        # TODO: check it with moy
        return db.session.query(Product).filter_by(id=1).first()
    if value == 'NSG':
        return db.session.query(Product).filter_by(id=6).first()
    if value == 'NVG':
        return db.session.query(Product).filter_by(id=7).first()
    if value == 'NTG':
        # TODO: check it with moy
        return db.session.query(Product).filter_by(id=1).first()
    if value == 'LyncExpress':
        return db.session.query(Product).filter_by(id=8).first()
    if value == 'VegaVideoMCU':
        return db.session.query(Product).filter_by(id=5).first()
    elif value == 'VegaESBC':
        return db.session.query(Product).filter_by(id=2).first()
    elif value == 'VegaESBC-VM-MAC' or value == 'VegaESBC-VM':
        return db.session.query(Product).filter_by(id=3).first()
    elif value == 'VegaESBC-Hybrid':
        return db.session.query(Product).filter_by(id=4).first()

    return None

def main():
    app = create_app(config.SQLALCHEMY_DATABASE_URI, debug=config.DEBUG)
    #app.config.from_object('config')
    app.config.from_object('conf.config.Configuration')
    with app.app_context():
        db.metadata.drop_all(bind=db.engine)
        db.metadata.create_all(bind=db.engine)

        if len(User.query.limit(1).all()) == 0:
           
            pool = Pool()
            pool.update(14000,0)
            db.session.add(pool)

            user = User()
            user.login = 'admin'
            user.email = 'admin@amdin'
            user.password = generate_password_hash('123')
            db.session.add(user)

            token = Token()
            token.token = 'token-d75c6e5426d47bf00d8af8bca7b93da4'
            db.session.add(token)

            p = Product()
            p.product = 'None'
            p.short_name = 'none'
            db.session.add(p)

            p = Product()
            p.product = 'NetBorder Carrier SBC'
            p.short_name = 'SBC-CAR'
            db.session.add(p)

            p = Product()
            p.product = 'Vega Enterprise SBC'
            p.short_name = 'SBC-ENT'
            db.session.add(p)

            p = Product()
            p.product = 'Vega Enterprise SBC VM'
            p.short_name = 'SBC-ENT-VM'
            db.session.add(p)

            p = Product()
            p.product = 'Vega Enterprise SBC Hybrid'
            p.short_name = 'SBC-ENT-HYBRID'
            db.session.add(p)

            p = Product()
            p.product = 'Vega Video MCU'
            p.short_name = 'MCU'
            db.session.add(p)

            p = Product()
            p.product = 'NetBorder SS7 Gateway'
            p.short_name = 'NSG'
            db.session.add(p)

            p = Product()
            p.product = 'NetBorder VoIP Gateway'
            p.short_name = 'NVG'
            db.session.add(p)

            p = Product()
            p.product = 'Lync Express'
            p.short_name = 'LyncExpress'
            db.session.add(p)

            k = KeyType()
            k.key_type = 'New License'
            db.session.add(k)

            k = KeyType()
            k.key_type = 'Upgrade'
            db.session.add(k)

            k = KeyState()
            k.key_state = 'Created'
            db.session.add(k)

            k = KeyState()
            k.key_state = 'Bounded'
            db.session.add(k)

            k = KeyState()
            k.key_state = 'Expired'
            db.session.add(k)

            k = KeyState()
            k.key_state = 'Upgraded'
            db.session.add(k)

            if os.path.isfile('legacy.csv-'):
                import csv

                with open('legacy.csv', 'rb') as f:
                    reader = csv.reader(f)
                    for row in reader:

                        #if row[0]:
                        #    print row

                        #continue

                        p = get_product(row[0])
                        if not p:
                            continue

                        k = Key()
                        k.product_id = p.id
                        k.serial = row[1]
                        k.key = row[2]
                        k.key_type_id = 1
                        k.key_state_id = 2
                        k.channels = row[3]

                        if row[4]:
                            try:
                                k.date_begin = datetime.datetime.strptime(row[4], '%Y-%m-%d').strftime("%m/%d/%Y")
                            except ValueError:
                                pass

                        if row[5]:
                            k.date_end = datetime.datetime.strptime(row[5], '%Y-%m-%d').strftime("%m/%d/%Y")

                        k.download_count = 0

                        data = row[6]
                        if data:
                            lst = []
                            hdd_list = 'none'
                            usb_list = 'none'
                            media_mac = 'none'
                            customer = ''
                            if '-' in data:
                                lst = data.split('-')

                            if row[0]:
                                if row[0] == 'NSG' or row[0] == 'NVG':

                                    if len(lst) > 1:
                                        customer = lst[0]
                                        if len(lst) > 1 and lst[1]:
                                            mac = lst[1]
                                            p_code = lst[2]
                                            if p_code == 'ANY':
                                                hdd_list = lst[3]
                                            #else:
                                            #    print '======> ', row[0], '   -   ', lst, " customer: ", customer, " mac: ", mac

                                elif row[0] == 'NSC' or row[0] == 'NTG' or 'VegaESBC' in row[0] or 'Vega Video MCU' in \
                                        row[0] or 'LyncExpress' in row[0] or 'VegaVideoMCU' in row[0]:

                                    customer = lst[0]
                                    if len(lst) > 1 and lst[1]:
                                        hdd_list = getval(lst[1])
                                    if len(lst) > 2 and lst[2]:
                                        usb_list = getval(lst[2])
                                    if len(lst) > 3 and lst[3]:
                                        media_mac = getval(lst[3])
                                else:
                                    print '======> ', row[0], '   -   ', lst

                        k.customer = customer

                        db.session.add(k)

                        a = KeyHistory()
                        a.key = k
                        a.activity = "created"
                        a.date = row[4]

                        db.session.add(a)

                        a = KeyHistory()
                        a.key = k
                        a.activity = "hardware-bind"
                        a.date = row[4]
                        a.data = json.dumps({
                            "hard-drives": hdd_list,
                            "usb-list": usb_list,
                            "media-mac-list": media_mac})

                        db.session.add(a)

            db.session.commit()


if __name__ == '__main__':
    main()
