import json
import config
from server import create_app

import unittest


class IndexTestCase(unittest.TestCase):

    def test_index(self):
        app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        tester = app.test_client()
        response = tester.get('/', content_type='html/text')
        self.assertEqual(response.status_code, 200)


class FaviconTestCase(unittest.TestCase):

    def test_index(self):

        app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        tester = app.test_client()
        response = tester.get('/favicon.ico', content_type='html/text')
        self.assertEqual(response.status_code, 200)


class PartialsTestCase(unittest.TestCase):

    def test_index(self):
        app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        tester = app.test_client()
        response = tester.get('/partials/api.html', content_type='html/text')
        self.assertEqual(response.status_code, 200)


class LicenseTestCase(unittest.TestCase):

    def test_index(self):
        app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        tester = app.test_client()
        response = tester.get('/license/saefasdfsaf', content_type='html/text')
        self.assertEqual(response.status_code, 200)

class LicenseViewTestCase(unittest.TestCase):
    def setUp(self):
        self.app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        self.client = self.app.test_client()

    def test_get(self):
        response = self.client.get('/api/v1/key/new', content_type='html/text')
        self.assertEqual(response.status_code, 200)

    def test_get_key_view(self):
        response = self.client.get('/api/v1/key/view', content_type='html/text')
        self.assertEqual(response.status_code, 200)

class NscLicenseCreationTestCase(unittest.TestCase):

    def setUp(self):
        self.app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        self.client = self.app.test_client()

    def test_get(self):
        response = self.client.get('/api/v1/license/nsc/new', content_type='html/text')
        self.assertEqual(response.status_code, 200)

    def test_post(self):
        response = self.client.post('/api/v1/license/nsc/new', data=dict(
            user_key='536xyrcbyh6',
            mac=''
        ));
        self.assertEqual(response.status_code, 200)


class NsgLicenseCreationTestCase(unittest.TestCase):

    def setUp(self):
        self.app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        self.client = self.app.test_client()

    def test_get(self):
        response = self.client.get('/api/v1/license/nsg/new', content_type='html/text')
        self.assertEqual(response.status_code, 200)

    def test_post(self):
        response = self.client.post('/api/v1/license/nsg/new', data=dict(
            user_key='536xyrcbyh6',
            mac=''
        ));
        self.assertEqual(response.status_code, 200)

class NscKeyGenerationTestCase(unittest.TestCase):
    key = None
    err_msg = None
    token = 'token-d75c6e5426d47bf00d8af8bca7b93da4'

    def setUp(self):
        self.app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        self.client = self.app.test_client()

    def test_key_01_generation(self):
        response = self.client.post('/api/v1/key/new', data=dict(
            request_token=self.__class__.token,
            customer='test-customer',
            product='SBC-ENT',
            channels=100
        ));
        self.assertEqual(response.status_code, 200)
        jr = json.loads(response.data)

        if jr['result'] == False:
            self.__class__.err_msg = jr['message']
        else:
            self.__class__.key = jr['generated_key']

        self.assertTrue(jr['result'], self.__class__.err_msg)

    def test_key_02_view(self):
        if self.__class__.key:
            response = self.client.post('/api/v1/key/view', data=dict(
                request_token=self.__class__.token,
                user_key=self.__class__.key,
            ));
            self.assertEqual(response.status_code, 200)
            jr = json.loads(response.data)

            if jr['result'] == False:
                self.__class__.err_msg = jr['message']

            self.assertTrue(jr['result'], self.__class__.err_msg)

    def test_key_03_bind(self):
        if self.__class__.key:
            response = self.client.post('/api/v1/license/nsc/new', data=dict(
                request_token=self.__class__.token,
                user_key=self.__class__.key,
                product='vega',
                hdd_list='01:22:03:44:05:66'
            ));
            self.assertEqual(response.status_code, 200)
            jr = json.loads(response.data)

            if jr['result'] == False:
                self.__class__.err_msg = jr['message']
            self.assertTrue(jr['result'], self.__class__.err_msg)

class NsgKeyGenerationTestCase(unittest.TestCase):
    key = None
    err_msg = None
    token = 'token-d75c6e5426d47bf00d8af8bca7b93da4'
    def setUp(self):
        self.app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        self.client = self.app.test_client()

    def test_key_01_generation(self):
        response = self.client.post('/api/v1/key/new', data=dict(
            request_token=self.__class__.token,
            user_token='token-d75c6e5426d47bf00d8af8bca7b93da4',
            customer='test-customer',
            product='NSG',
            channels=100
        ));
        self.assertEqual(response.status_code, 200)
        jr = json.loads(response.data)
        if jr['result'] == False:
            self.__class__.err_msg = jr['message']
        else:
            self.__class__.key = jr['generated_key']
        self.assertTrue(jr['result'], self.__class__.err_msg)

    def test_key_02_view(self):
        if self.__class__.key:
            response = self.client.post('/api/v1/key/view', data=dict(
                request_token=self.__class__.token,
                user_key=self.__class__.key,
            ));
            self.assertEqual(response.status_code, 200)
            jr = json.loads(response.data)
            if jr['result'] == False:
                self.__class__.err_msg = jr['message']
            self.assertTrue(jr['result'], self.__class__.err_msg)

    def test_key_03_bind(self):
        if self.__class__.key:
            response = self.client.post('/api/v1/license/nsg/new', data=dict(
                request_token=self.__class__.token,
                user_key=self.__class__.key,
                product='nsg-binary',
                itu_pcode='1234',
                mac='08-00-27-06-45-BE'
            ));
            self.assertEqual(response.status_code, 200)
            jr = json.loads(response.data)
            if jr['result'] == False:
                self.__class__.err_msg = jr['message']
            self.assertTrue(jr['result'], self.__class__.err_msg)

class NvgKeyGenerationTestCase(unittest.TestCase):
    key = None
    err_msg = None
    token = 'token-d75c6e5426d47bf00d8af8bca7b93da4'

    def setUp(self):
        self.app = create_app(config.SQLALCHEMY_DATABASE_TEST_URI, True)
        self.client = self.app.test_client()

    def test_key_01_generation(self):
        response = self.client.post('/api/v1/key/new', data=dict(
            request_token='token-d75c6e5426d47bf00d8af8bca7b93da4',
            customer='test-customer',
            product='NVG',
            channels=100
        ));
        self.assertEqual(response.status_code, 200)
        jr = json.loads(response.data)
        if jr['result'] == False:
            self.__class__.err_msg = jr['message']
        else:
            self.__class__.key = jr['generated_key']
        self.assertTrue(jr['result'], self.__class__.err_msg)

    def test_key_02_view(self):
        if self.__class__.key:
            response = self.client.post('/api/v1/key/view', data=dict(
                request_token='token-d75c6e5426d47bf00d8af8bca7b93da4',
                user_key=self.__class__.key,
            ));
            self.assertEqual(response.status_code, 200)
            jr = json.loads(response.data)
            if jr['result'] == False:
                self.__class__.err_msg = jr['message']
        
            self.assertTrue(jr['result'], self.__class__.err_msg)

    def test_key_03_bind(self):
        if self.__class__.key:
            response = self.client.post('/api/v1/license/nsg/new', data=dict(
                request_token='token-d75c6e5426d47bf00d8af8bca7b93da4',
                user_key=self.__class__.key,
                product='nvg-appliance',
                hdd_list='20120109483130043247',
                mac='08-00-27-06-45-BE'
            ));
            self.assertEqual(response.status_code, 200)
            jr = json.loads(response.data)
            if jr['result'] == False:
                self.__class__.err_msg = jr['message']
        
            self.assertTrue(jr['result'], self.__class__.err_msg)


if __name__ == '__main__':
    unittest.main()
